@@ -8,35 +8,30 @@ from palp.tool.create_project import CreateProject
 
 
 def generator():
-    spider = argparse.ArgumentParser(description="创建爬虫模板")
+    if len(sys.argv) == 1:
+        sys.argv.append('--h')  # 无参数默认输出帮助
 
-    spider.add_argument(
-        '-p', '--project', help='创建爬虫项目如：palp create -p <project_name>'
-    )
-    spider.add_argument(
-        "-s",
-        "--spider",
-        nargs="+",
-        help="创建爬虫\n"
-             "如 palp create -s <spider_name> <spider_type> "
-             "spider_type=1  Spider; "
-             "spider_type=2  DistributiveSpider; ",
-    )
-    args = spider.parse_args()
+    parser = argparse.ArgumentParser(description="Palp 创建爬虫模板")
+    parser.add_argument('-p', '--project', help='创建爬虫项目如：palp create -p <project_name>')
+    parser.add_argument('-s', '--spider', nargs='+', help='创建爬虫如：palp create -s <spider_name> <spider_type>')
+    args = parser.parse_args()
 
+    # 创建 spider
     if args.spider:
-        spider_name, *spider_type = args.spider
-        if not spider_type:
+        args_spider = args.spider
+        if len(args_spider) == 1:
+            spider_name = args_spider[0]
             spider_type = 1
         else:
-            spider_type = spider_type[0]
-        try:
-            spider_type = int(spider_type)
-        except:
-            raise ValueError("spider 参数只支持：1, 2")
+            spider_name = args_spider[0]
+            spider_type = int(args_spider[1])
+
+        if spider_type not in [1, 2]:
+            raise ValueError('spider 只能是 1 或 2 ！')
         CreateSpider(spider_name, spider_type).create()
 
-    elif args.project:
+    # 创建项目
+    if args.project:
         project_name = args.project
         CreateProject(project_name).create()
 
